@@ -3,10 +3,12 @@ package Moo;
 use Moo::_strictures;
 use Moo::_mro;
 use Moo::_Utils qw(
+  _check_tracked
   _getglob
   _getstash
   _install_coderef
   _install_modifier
+  _install_tracked
   _load_module
   _set_loaded
   _unimport_coderefs
@@ -23,7 +25,7 @@ BEGIN {
   );
 }
 
-our $VERSION = '2.003003';
+our $VERSION = '2.003006';
 $VERSION =~ tr/_//d;
 
 require Moo::sification;
@@ -31,12 +33,6 @@ Moo::sification->import;
 
 our %MAKERS;
 
-sub _install_tracked {
-  my ($target, $name, $code) = @_;
-  $MAKERS{$target}{exports}{$name} = $code;
-  _install_coderef "${target}::${name}" => "Moo::${name}" => $code;
-}
-
 sub import {
   my $target = caller;
   my $class = shift;
@@ -86,11 +82,15 @@ sub import {
     };
   }
   return if $MAKERS{$target}{is_class}; # already exported into this package
+
   my $stash = _getstash($target);
-  my @not_methods = map +(
-    !ref($_) ? *$_{CODE}||() : reftype($_) eq 'CODE' ? $_ : ()
-  ), values %$stash;
-  @{$MAKERS{$target}{not_methods}={}}{@not_methods} = @not_methods;
+  $MAKERS{$target}{non_methods} = {
+    map +($_ => \&{"${target}::${_}"}),
+    grep exists &{"${target}::${_}"},
+    grep !/::\z/ && !/\A\(/,
+    keys %$stash
+  };
+
   $MAKERS{$target}{is_class} = 1;
   {
     no strict 'refs';
@@ -105,7 +105,7 @@ sub import {
 
 sub unimport {
   my $target = caller;
-  _unimport_coderefs($target, $MAKERS{$target});
+  _unimport_coderefs($target);
 }
 
 sub _set_superclasses {
@@ -234,18 +234,28 @@ sub _constructor_maker_for {
 sub _concrete_methods_of {
   my ($me, $class) = @_;
   my $makers = $MAKERS{$class};
-  # grab class symbol table
+
+  my $non_methods = $makers->{non_methods} || {};
   my $stash = _getstash($class);
-  # reverse so our keys become the values (captured coderefs) in case
-  # they got copied or re-used since
-  my $not_methods = { reverse %{$makers->{not_methods}||{}} };
-  +{
-    # grab all code entries that aren't in the not_methods list
+
+  my $subs = {
     map {;
       no strict 'refs';
-      my $code = exists &{"${class}::$_"} ? \&{"${class}::$_"} : undef;
-      ( ! $code or exists $not_methods->{$code} ) ? () : ($_ => $code)
-    } grep +(!ref($stash->{$_}) || reftype($stash->{$_}) eq 'CODE'), keys %$stash
+      ${"${class}::${_}"} = ${"${class}::${_}"};
+      ($_ => \&{"${class}::${_}"});
+    }
+    grep exists &{"${class}::${_}"},
+    grep !/::\z/,
+    keys %$stash
+  };
+
+  my %tracked = map +($_ => 1), _check_tracked($class, [ keys %$subs ]);
+
+  return {
+    map +($_ => \&{"${class}::${_}"}),
+    grep !($non_methods->{$_} && $non_methods->{$_} == $subs->{$_}),
+    grep !exists $tracked{$_},
+    keys %$subs
   };
 }
 
@@ -314,7 +324,8 @@ optimised for rapid startup.
 
 C<Moo> avoids depending on any XS modules to allow for simple deployments.  The
 name C<Moo> is based on the idea that it provides almost -- but not quite --
-two thirds of L<Moose>.
+two thirds of L<Moose>.  As such, the L<Moose::Manual> can serve as an effective
+guide to C<Moo> aside from the MOP and Types sections.
 
 Unlike L<Mouse> this module does not aim at full compatibility with
 L<Moose>'s surface syntax, preferring instead to provide full interoperability
@@ -404,7 +415,7 @@ dependencies but is also fully usable by L<Moose> users, you should be using
 L<Moo>.
 
 For a full explanation, see the article
-L<http://shadow.cat/blog/matt-s-trout/moo-versus-any-moose> which explains
+L<https://shadow.cat/blog/matt-s-trout/moo-versus-any-moose> which explains
 the differing strategies in more detail and provides a direct example of
 where L<Moo> succeeds and L<Any::Moose> fails.
 
@@ -893,9 +904,17 @@ Anything imported or declared after will be still be available.
 
   1;
 
-If you were to import C<md5_hex> after L<namespace::clean> you would
-be able to call C<< ->md5_hex() >> on your C<Record> instances (and it
-probably wouldn't do what you expect!).
+For example if you were to import these subroutines after
+L<namespace::clean> like this
+
+  use namespace::clean;
+
+  use Digest::MD5 qw(md5_hex);
+  use Moo;
+
+then any C<Record> C<$r> would have methods such as C<< $r->md5_hex() >>, 
+C<< $r->has() >> and C<< $r->around() >> - almost certainly not what you
+intend!
 
 L<Moo::Role>s behave slightly differently.  Since their methods are
 composed into the consuming class, they can do a little more for you
@@ -911,6 +930,8 @@ using version 0.16 or newer.
 
 =head1 INCOMPATIBILITIES WITH MOOSE
 
+=head2 TYPES
+
 There is no built-in type system.  C<isa> is verified with a coderef; if you
 need complex types, L<Type::Tiny> can provide types, type libraries, and
 will work seamlessly with both L<Moo> and L<Moose>.  L<Type::Tiny> can be
@@ -920,18 +941,12 @@ that you can write
   use Types::Standard qw(Int);
   has days_to_live => (is => 'ro', isa => Int);
 
+=head2 API INCOMPATIBILITIES
+
 C<initializer> is not supported in core since the author considers it to be a
 bad idea and Moose best practices recommend avoiding it. Meanwhile C<trigger> or
 C<coerce> are more likely to be able to fulfill your needs.
 
-There is no meta object.  If you need this level of complexity you need
-L<Moose> - Moo is small because it explicitly does not provide a metaprotocol.
-However, if you load L<Moose>, then
-
-  Class::MOP::class_of($moo_class_or_role)
-
-will return an appropriate metaclass pre-populated by L<Moo>.
-
 No support for C<super>, C<override>, C<inner>, or C<augment> - the author
 considers augment to be a bad idea, and override can be translated:
 
@@ -950,7 +965,7 @@ considers augment to be a bad idea, and override can be translated:
 
 The C<dump> method is not provided by default. The author suggests loading
 L<Devel::Dwarn> into C<main::> (via C<perl -MDevel::Dwarn ...> for example) and
-using C<$obj-E<gt>$::Dwarn()> instead.
+using C<< $obj->$::Dwarn() >> instead.
 
 L</default> only supports coderefs and plain scalars, because passing a hash
 or array reference as a default is almost always incorrect since the value is
@@ -1001,6 +1016,18 @@ or, if you're inheriting from a non-Moose class,
   use warnings FATAL => "all";
   use MooseX::AttributeShortcuts;
 
+=head2 META OBJECT
+
+There is no meta object.  If you need this level of complexity you need
+L<Moose> - Moo is small because it explicitly does not provide a metaprotocol.
+However, if you load L<Moose>, then
+
+  Class::MOP::class_of($moo_class_or_role)
+
+will return an appropriate metaclass pre-populated by L<Moo>.
+
+=head2 IMMUTABILITY
+
 Finally, Moose requires you to call
 
   __PACKAGE__->meta->make_immutable;
@@ -1014,15 +1041,10 @@ to Moo by providing a more Moose-like interface.
 
 =head1 SUPPORT
 
-Users' IRC: #moose on irc.perl.org
+IRC: #moose on irc.perl.org
 
 =for :html
-L<(click for instant chatroom login)|http://chat.mibbit.com/#moose@irc.perl.org>
-
-Development and contribution IRC: #web-simple on irc.perl.org
-
-=for :html
-L<(click for instant chatroom login)|http://chat.mibbit.com/#web-simple@irc.perl.org>
+L<(click for instant chatroom login)|https://chat.mibbit.com/#moose@irc.perl.org>
 
 Bugtracker: L<https://rt.cpan.org/Public/Dist/Display.html?Name=Moo>
 
@@ -1078,6 +1100,6 @@ as listed above.
 =head1 LICENSE
 
 This library is free software and may be distributed under the same terms
-as perl itself. See L<http://dev.perl.org/licenses/>.
+as perl itself. See L<https://dev.perl.org/licenses/>.
 
 =cut
